django\_model\_cleanup package
==============================

Submodules
----------

django\_model\_cleanup\.admin module
------------------------------------

.. automodule:: django_model_cleanup.admin
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.app\_settings module
--------------------------------------------

.. automodule:: django_model_cleanup.app_settings
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.apps module
-----------------------------------

.. automodule:: django_model_cleanup.apps
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.cli module
----------------------------------

.. automodule:: django_model_cleanup.cli
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.factories module
----------------------------------------

.. automodule:: django_model_cleanup.factories
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.forms module
------------------------------------

.. automodule:: django_model_cleanup.forms
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.models module
-------------------------------------

.. automodule:: django_model_cleanup.models
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.resources module
----------------------------------------

.. automodule:: django_model_cleanup.resources
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.urls module
-----------------------------------

.. automodule:: django_model_cleanup.urls
    :members:
    :undoc-members:
    :show-inheritance:

django\_model\_cleanup\.views module
------------------------------------

.. automodule:: django_model_cleanup.views
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_model_cleanup
    :members:
    :undoc-members:
    :show-inheritance:
